##  Step 5: Add IT Components to Applications
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d993f7a441014b4d4f507631d9249_LowRes.gif)
  1. Navigate to the Fact Sheet of choice.
  2. Go to the Sourcing section.
  3. Hover over the IT Components section, and click the Add button (use the "..." button for multi-select).
  4. Search for the IT Component that you would like to associate, fill out other info as required, and click Save.
